==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralBooleanSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.LiteralBoolean;
import io.ciera.tool.sql.ooaofooa.value.LiteralBooleanSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class LiteralBooleanSetImpl extends InstanceSet<LiteralBooleanSet,LiteralBoolean> implements LiteralBooleanSet {

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( LiteralBoolean literalboolean : this ) literalboolean.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( LiteralBoolean literalboolean : this ) literalboolean.setValue( m_Value );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( LiteralBoolean literalboolean : this ) valueset.add( literalboolean.R801_is_a_Value() );
        return valueset;
    }


    @Override
    public LiteralBoolean nullElement() {
        return LiteralBooleanImpl.EMPTY_LITERALBOOLEAN;
    }

    @Override
    public LiteralBooleanSet emptySet() {
      return new LiteralBooleanSetImpl();
    }

    @Override
    public LiteralBooleanSet value() {
        return this;
    }

    @Override
    public List<LiteralBoolean> elements() {
        return Arrays.asList(toArray(new LiteralBoolean[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralBooleanSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.LiteralBoolean;
import io.ciera.tool.sql.ooaofooa.value.LiteralBooleanSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class LiteralBooleanSetImpl extends InstanceSet<LiteralBooleanSet,LiteralBoolean> implements LiteralBooleanSet {

    public LiteralBooleanSetImpl() {
    }

    public LiteralBooleanSetImpl(Comparator<? super LiteralBoolean> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( LiteralBoolean literalboolean : this ) literalboolean.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( LiteralBoolean literalboolean : this ) literalboolean.setValue( m_Value );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( LiteralBoolean literalboolean : this ) valueset.add( literalboolean.R801_is_a_Value() );
        return valueset;
    }


    @Override
    public LiteralBoolean nullElement() {
        return LiteralBooleanImpl.EMPTY_LITERALBOOLEAN;
    }

    @Override
    public LiteralBooleanSet emptySet() {
      return new LiteralBooleanSetImpl();
    }

    @Override
    public LiteralBooleanSet emptySet(Comparator<? super LiteralBoolean> comp) {
      return new LiteralBooleanSetImpl(comp);
    }

    @Override
    public LiteralBooleanSet value() {
        return this;
    }

    @Override
    public List<LiteralBoolean> elements() {
        return Arrays.asList(toArray(new LiteralBoolean[0]));
    }

}
